from tablate.classes.options.html.style.utilities.style_types import ElementTypeKey, TablateInstanceKey

base_class = "tablate"

styles_key = "styles"

tablate_instance_key: TablateInstanceKey = "tablate_instance"
element_type_key: ElementTypeKey = "element_type"

style_defaults = {

}