from typing import Dict

from tablate.type.primitives import Colors

ascii_character_colors: Dict[Colors, str] = {
    "default": "",
    "white": "97",
    "grey": "37",
    "red": "91",
    "green": "92",
    "yellow": "93",
    "blue": "94",
    "magenta": "95",
    "cyan": "96",
    "dark_red": "31",
    "dark_green": "32",
    "dark_yellow": "33",
    "dark_blue": "34",
    "dark_magenta": "35",
    "dark_cyan": "36",
    "dark_grey": "90",
    "black": "30",
}
